<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Bildschirmfoto erstellen</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot to folder without gui</source>
        <translation>Screenshot aufnehmen ohne GUI</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[DATEI1, DATEI2, ...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>unbekannte Fehlerantwort</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>Unbekannte Fehlermeldung</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>unbekannte Fehlerantwort</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - ein einfacher und schneller Bildbetrachter

Copyright (C) 2013
LXQt-Projekt: https://lxqt.org/

Autoren:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Image files (%1)</source>
        <translation>Bilddateien (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Open directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Lade...) - Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Laden ist fehlgeschlagen) - Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="992"/>
        <source>Thumbnails</source>
        <translation>Miniaturen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>EXIF Data</source>
        <translation>EXIF-Daten</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="45"/>
        <source>&amp;Clear</source>
        <translation>Lös&amp;chen</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Bildbetrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Annotations Toolbar</source>
        <translation>Anmerkungssymbolleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Ctrl+O</source>
        <translatorcomment>Shortcuts are translated automatically. No need to manually translate it to &quot;Strg+O&quot;.</translatorcomment>
        <translation>Strg+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Ctrl+S</source>
        <translation>Strg+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Ctrl+A</source>
        <translation>Strg+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>Ctrl+W</source>
        <translation>Strg+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>In die Zwischenablage &amp;kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Next File</source>
        <translation>Nächste Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="317"/>
        <source>Previous File</source>
        <translation>Vorherige Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>PgDown</source>
        <translation>Bild ab</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>&amp;Open…</source>
        <translation>&amp;Öffnen…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&amp;Reload File</source>
        <translation>Datei &amp;neu laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Ctrl+R</source>
        <translation>Strg+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Ctrl+=</source>
        <translation>Strg+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>PgUp</source>
        <translation>Bild auf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Original Size</source>
        <translation>Originalgröße</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+0</source>
        <translation>Strg+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Fit</source>
        <translation>&amp;Passend</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Im Uhrzeigersinn &amp;drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>&amp;Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>P&amp;references</source>
        <translation>Einste&amp;llungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>&amp;Print</source>
        <translation>&amp;Drucken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Ctrl+P</source>
        <translation>Strg+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>First File</source>
        <translation>Erste Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Home</source>
        <translation>Pos1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="399"/>
        <source>Last File</source>
        <translation>Letzte Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>&amp;New Window</source>
        <translation>&amp;Neues Fenster</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Ctrl+N</source>
        <translation>Strg+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Horizontal spiegeln</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Capture Screenshot</source>
        <translation>Bildschirmfoto aufnehmen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Gesamter Bildschirm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Flip &amp;Vertically</source>
        <translation>&amp;Vertikal spiegeln</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Aus Zwischenablage &amp;einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaschau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Del</source>
        <translation>Entf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Show Thumbnails</source>
        <translation>Vorschaubilder anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>File Properties</source>
        <translatorcomment>Translation of &apos;file&apos; skipped, it is redundant (this is the file menu).</translatorcomment>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Open &amp;Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Ctrl+D</source>
        <translation>Strg+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Upload the image</source>
        <translation>Bild hochladen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Show EXIF Data</source>
        <translation>EXIF-Daten anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>No Tool</source>
        <translation>Kein Werkzeug</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Deselect all drawing tools</source>
        <translation>Alle Zeichenwerkzeuge abwählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Draw Arrow</source>
        <translation>Pfeil zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Draw an arrow</source>
        <translation>Einen Pfeil zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Draw Rectangle</source>
        <translation>Rechteck zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Draw a hollow rectangle</source>
        <translation>Ein hohles Rechteck zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Draw Circle</source>
        <translation>Kreis zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Draw a hollow circle</source>
        <translation>Einen hohlen Kreis zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Draw Number</source>
        <translation>Zahl zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Draw incrementing numbers</source>
        <translation>Inkrementierende Zahlen zeichnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Anmerkungssymbolleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Show Outline</source>
        <translation>Zeige Umriss</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>Go</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>Toolbar</source>
        <translation>Werkzeugleiste</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Symbolthema:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normale Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Vollbild-Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Diaschau-Intervall (Sekunden):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="85"/>
        <source>Show image outline by default</source>
        <translation>Standardmäßig Bildkontur anzeigen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="92"/>
        <source>Show annotations toolbar by default</source>
        <translation>Standardmäßig Anmerkungssymbolleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Bildschirmfoto</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Bildschirmfoto machen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Gesamter Bildschirm</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Nur aktuelles Fenster</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Bildschirmbereich aufnehmen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Einschließlich Mauszeiger</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Verzögerung:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Einschließlich Fenstertitel und Rahmen</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
</context>
</TS>
